# BatchModifyMessagesRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**add_label_ids** | **list[str]** | A list of label IDs to add to messages. | [optional] 
**ids** | **list[str]** | The IDs of the messages to modify. There is a limit of 1000 ids per request. | [optional] 
**remove_label_ids** | **list[str]** | A list of label IDs to remove from messages. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

